@@ -68,16 +68,16 @@ Boston, MA 02111-1307, USA.  */
 #undef OBSD_LINK_SPEC
 #ifdef OBSD_NO_DYNAMIC_LIBRARIES
 #define OBSD_LINK_SPEC \
-  "%{!nostdlib:%{!r*:%{!e*:-e __start}}} %{assert*}"
+  "%{!nostdlib:%{!r:%{!e*:-e __start}}} %{assert*}"
 #else
 #define OBSD_LINK_SPEC \
-  "%{!shared:%{!nostdlib:%{!r*:%{!e*:-e __start}}}} \
+  "%{!shared:%{!nostdlib:%{!r:%{!e*:-e __start}}}} \
    %{shared:-shared} %{R*} \
    %{static:-Bstatic} \
    %{!static:-Bdynamic} \
    %{rdynamic:-export-dynamic} \
    %{assert*} \
-   %{!dynamic-linker:-dynamic-linker /usr/libexec/ld.so} \
+   %{!static:-dynamic-linker /usr/libexec/ld.so} \
    %{!nostdlib:-L/usr/lib}"
 #endif
 
