@@ -1,6 +1,6 @@
 /* Configuration for an OpenBSD i386 target.
    
-   Copyright (C) 2005-2014 Free Software Foundation, Inc.
+   Copyright (C) 2005-2018 Free Software Foundation, Inc.
 
 This file is part of GCC.
 
@@ -99,12 +99,12 @@ along with GCC; see the file COPYING3.  If not see
    %{!static:-Bdynamic} \
    %{rdynamic:-export-dynamic} \
    %{assert*} \
-   -dynamic-linker /usr/libexec/ld.so \
+   %{!shared:%{!-dynamic-linker:-dynamic-linker /usr/libexec/ld.so}} \
    -L/usr/lib"
 
 #undef STARTFILE_SPEC
 
-#define SUBTARGET32_DEFAULT_CPU "i486"
+#define SUBTARGET32_DEFAULT_CPU "i586"
 #define STARTFILE_SPEC "\
 	%{!shared: %{pg:gcrt0%O%s} %{!pg:%{p:gcrt0%O%s} \
 	%{!p:%{!static:crt0%O%s} %{static:%{nopie:crt0%O%s} \
@@ -115,9 +115,3 @@ along with GCC; see the file COPYING3.  If not see
 #define OBSD_HAS_CORRECT_SPECS
 
 #define HAVE_ENABLE_EXECUTE_STACK
-
-/* Put all *tf routines in libgcc.  */
-#undef LIBGCC2_HAS_TF_MODE
-#define LIBGCC2_HAS_TF_MODE 1
-#define LIBGCC2_TF_CEXT q
-#define TF_SIZE 113
