@@ -13,8 +13,8 @@
 #ifndef TARGET_ENDIAN_DEFAULT
 # define TARGET_ENDIAN_DEFAULT 0
 #endif
-#ifndef PIE_DEFAULT
-# define PIE_DEFAULT 1
+#ifndef DEFAULT_FLAG_PIE
+# define DEFAULT_FLAG_PIE 1
 #endif
 #ifdef IN_GCC
 # include "options.h"
@@ -22,6 +22,7 @@
 # include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/openbsd.h"
+# include "config/openbsd-stdint.h"
 # include "config/mips/mips.h"
 # include "config/mips/openbsd.h"
 # include "config/openbsd-libpthread.h"
