@@ -9,8 +9,11 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
-#ifndef PIE_DEFAULT
-# define PIE_DEFAULT 1
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
+#ifndef DEFAULT_FLAG_PIE
+# define DEFAULT_FLAG_PIE 1
 #endif
 #ifdef IN_GCC
 # include "options.h"
